@@ -23,11 +23,9 @@ from typing import (
 from robot.parsing.lexer.tokens import Token
 from robot.parsing.model.statements import (
     Arguments,
-    Documentation,
     Fixture,
     KeywordCall,
     LibraryImport,
-    Metadata,
     ResourceImport,
     Statement,
     Template,
@@ -116,6 +114,7 @@ class RobotSemTokenTypes(Enum):
     CONFIG = "config"
     NAMED_ARGUMENT = "namedArgument"
     VAR = "var"
+    DOCUMENTATION = "documentation"
 
 
 class RobotSemTokenModifiers(Enum):
@@ -345,10 +344,10 @@ class RobotSemanticTokenProtocolPart(RobotLanguageServerProtocolPart):
         if sem_info is not None:
             sem_type, sem_mod = sem_info
 
-            if isinstance(node, (Documentation, Metadata)):
+            if token.type in [Token.DOCUMENTATION, Token.METADATA]:
                 sem_mod = {SemanticTokenModifiers.DOCUMENTATION}
 
-            if token.type == Token.VARIABLE:
+            if token.type in [Token.VARIABLE, Token.ASSIGN]:
                 if is_variable(token.value, "$@&%"):
                     if col_offset is None:
                         col_offset = token.col_offset
@@ -368,14 +367,6 @@ class RobotSemanticTokenProtocolPart(RobotLanguageServerProtocolPart):
                             sem_mod,
                         )
 
-                        # yield SemTokenInfo.from_token(
-                        #     token,
-                        #     RobotSemTokenTypes.VARIABLE_EXPRESSION if is_expr else sem_type,
-                        #     sem_mod,
-                        #     col_offset + (3 if is_expr else 2),
-                        #     last_index - (4 if is_expr else 2),
-                        # )
-
                         yield SemTokenInfo(
                             token.lineno,
                             col_offset + ((last_index - 1) if is_expr else last_index),
@@ -398,18 +389,6 @@ class RobotSemanticTokenProtocolPart(RobotLanguageServerProtocolPart):
                 else:
                     yield SemTokenInfo.from_token(token, sem_type, sem_mod)
 
-            elif token.type == Token.ARGUMENT and "\\" in token.value:
-                if col_offset is None:
-                    col_offset = token.col_offset
-
-                for g in cls.ESCAPE_REGEX.finditer(token.value):
-                    yield SemTokenInfo.from_token(
-                        token,
-                        sem_type if g.group("x") is None else RobotSemTokenTypes.ESCAPE,
-                        sem_mod,
-                        col_offset + g.start(),
-                        g.end() - g.start(),
-                    )
             elif token.type in [Token.KEYWORD, ROBOT_KEYWORD_INNER] or (
                 token.type == Token.NAME and isinstance(node, (Fixture, Template, TestTemplate))
             ):
@@ -614,7 +593,8 @@ class RobotSemanticTokenProtocolPart(RobotLanguageServerProtocolPart):
                     1,
                 )
             else:
-                yield SemTokenInfo.from_token(token, sem_type, sem_mod, col_offset, length)
+                if token.type != Token.ARGUMENT:
+                    yield SemTokenInfo.from_token(token, sem_type, sem_mod, col_offset, length)
 
     def generate_sem_tokens(
         self,
